# tests/test_module2.py

import unittest
from nnthvn.module2 import to_uppercase, reverse_string


class TestStringFunctions(unittest.TestCase):
    def test_to_uppercase(self):
        self.assertEqual(to_uppercase("hello"), "HELLO")
        self.assertEqual(to_uppercase("Hello"), "HELLO")
        self.assertEqual(to_uppercase("HELLO"), "HELLO")

    def test_reverse_string(self):
        self.assertEqual(reverse_string("hello"), "olleh")
        self.assertEqual(reverse_string("abc"), "cba")
        self.assertEqual(reverse_string("racecar"), "racecar")  # Палиндром


if __name__ == "__main__":
    unittest.main()













from setuptools import setup, find_packages

setup(
    name='nnthvn',
    version='0.6.0',
    author='',
    author_email='jaguar80605@gmail.ru',
    description='Простая библиотека для работы с числами и строками.',
    long_description=open('README.md', encoding="utf-8").read(),
    long_description_content_type='text/markdown',
    url='https://github.com/NeonitTHeav3n/nnthvn',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[],
)
